==> haskell-ghcide-test-utils-1.9.0.0-252-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-E1X9Kpt7G834sJUeKo3m2s
key:                  ghcide-test-utils-1.9.0.0-E1X9Kpt7G834sJUeKo3m2s
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  4302cc37b853a703a1d6b343f4d132af
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-E1X9Kpt7G834sJUeKo3m2s
depends:
    aeson-2.1.2.1-Kx5U0b11hXDAcrJPuBeHuf base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    extra-1.7.16-5tezMKqv9GA6gNR4q67AdR filepath-1.4.2.2
    ghcide-2.1.0.0-JFanyDP6TiN9YNvtBtscgo
    hls-plugin-api-2.1.0.0-JEKlXQXeaW9Ka0MbLGh5py
    lens-5.3.2-LURSnBuXCqTHeh00mrfrRc
    lsp-test-0.15.0.1-6oPn8dTLMHkJkF8Oo57A26
    lsp-types-2.0.1.0-7oy9Lfs26XsFHT15gvLibi
    tasty-hunit-0.10.2-6hG5t2Q6esED4xj0XQHnJ4 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-test-utils-1.9.0.0-253-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-JskSaQQ4EMS5qApwfHEHbt
key:                  ghcide-test-utils-1.9.0.0-JskSaQQ4EMS5qApwfHEHbt
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  50f9c29a52b7257f303b14e04f6fdaef
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-JskSaQQ4EMS5qApwfHEHbt
depends:
    aeson-2.1.2.1-DAjCoZEGWBTDXHPn96Kb1j base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    extra-1.7.16-JyTxBhiayTkLmgcKeg6bhV filepath-1.4.2.2
    ghcide-2.1.0.0-H2NFu3PHXDPIaAWPGi5kSs
    hls-plugin-api-2.1.0.0-A1iEMAxLSa5CaBb4hrWoPw
    lens-5.3.2-5iQf9T9ZD7E1oav0YIbKON
    lsp-test-0.15.0.1-4Yu5IZFAx9R1ujRy8s18RG
    lsp-types-2.0.1.0-4BhwIVcG1LCePiTj9eZi9
    tasty-hunit-0.10.2-58ExgjwPSX258cSgtkBEVQ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
